import * as ts from 'typescript';
export declare const defaultOptions: {
    /**
     * React.lazy() only offically supports default exports, but it works if you do:
     * `React.lazy(() => import('./x').then(m => ({ default: m.Xyz })))`
     * This lets you rewrite all imported components. Once React supports a better way to import
     * named exports this transform will be updated to that.
     */
    onlyRewriteDefaultExports: boolean;
    /**
     * If the import declaration can't be removed because both a component and another function
     * is imported this lets you skip converting to a lazy component since it'll probably be
     * placed in the same bundle either way. The default is `false` since other imports might
     * be dead code eliminated without this transform knowing about it.
     */
    onlyRewriteIfImportCanBeRemoved: boolean;
    /**
     * Defaults to creating a PropertyAccessExpression of `React.lazy` but can be any expression you want.
     * Use `Options.createImportDeclaration()` if you need to import something from another module to call.
     */
    createComponentWrapperExpression: (typescript: typeof ts) => ts.Expression;
    /**
     * Implement this if you want to import another module which contains your wrapper expression.
     * This can be used if you want to replace `React.lazy()` with something else.
     */
    createImportDeclaration: (typescript: typeof ts, currentFile: string) => ts.ImportDeclaration | null;
    /**
     * This lets you bail on rewriting imports on a per import declaration basis. If you have a list of
     * files to load sync (from for example https://github.com/avensia-oss/ts-transform-instrument-react-components)
     * you can implement this function to only rewrite imports from those files.
     */
    shouldRewrite: (importSpecifier: string, currentFile: string) => boolean;
};
export declare type Options = typeof defaultOptions;
export default function transformer(program: ts.Program, options?: Partial<Options>): ts.TransformerFactory<ts.SourceFile>;
